@@ -37,5 +37,5 @@ readCoordsJS <- function(filename) {
   jsData <- readLines(filename)
   jsData <- gsub("var gridSVGCoords = ", "", jsData)
   jsonData <- gsub(";$", "", jsData)
-  paste0(jsonData, collapse = "\n")
+  fromJSON(paste0(jsonData, collapse = "\n"))
 }
